package
Version:
v0.0.0-...-0120b79
Opens a new window with list of versions in this module.
Published: Jan 20, 2021
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package stream defines http client for Stream API
Client holds our connection to Stream
func Connect(apiKey, apiSecret, apiRegion string) error
Connect -- connect to Stream, set our Client variable or report error
params:
apiKey - string, Stream API key
apiSecret - string, Stream API Secret
apiRegion - string, Stream region (ie, "us-east", "eu-central")
Source Files
¶
Click to show internal directories.
Click to hide internal directories.